#
#    (c) Copyright 2014 Hewlett-Packard Development Company, L.P.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from django.conf import settings
from django.utils.translation import gettext_lazy as _

import horizon

from openstack_dashboard.api import glance


class MetadataDefinitions(horizon.Panel):
    name = _("Metadata Definitions")
    slug = 'metadata_defs'
    policy_rules = ((("image", "context_is_admin"),
                     ("image", "get_metadef_namespaces")),)
    permissions = ('openstack.services.image',)

    @staticmethod
    def can_register():
        return glance.VERSIONS.active >= 2

    def allowed(self, context):
        if (('image' in settings.SYSTEM_SCOPE_SERVICES) !=
                bool(context['request'].user.system_scoped)):
            return False
        return super().allowed(context)
